//
// Source code recreated from a .class file by IntelliJ IDEA
// (powered by FernFlower decompiler)
//

package nc.itf.mmpac.pickm;

import java.util.List;
import java.util.Map;

import nc.ui.querytemplate.querytree.IQueryScheme;
import nc.vo.bd.material.MaterialVersionVO;
import nc.vo.mmpac.pickm.entity.AggPickmVO;
import nc.vo.mmpac.pickm.entity.MaterialQueryCondition;
import nc.vo.mmpac.pickm.entity.MaterialRelationItem;
import nc.vo.mmpac.pickm.entity.PickmHeadVO;
import nc.vo.mmpac.pickm.entity.PickmItemVO;
import nc.vo.mmpac.pickm.param.PickmParamForAdd;
import nc.vo.mmpac.pickm.param.PickmQueryMOParamForSetDelivery;
import nc.vo.mmpac.pickm.param.PickmTransParamForPlanReplace;
import nc.vo.pub.BusinessException;
import nc.vo.pub.lang.UFBoolean;
import nc.vo.pubapp.pattern.pub.MapList;

public interface IPickmQueryService {
    Object[] queryByWhereSql(String paramString, Class paramClass, boolean paramBoolean, String[] paramArrayOfString) throws BusinessException;

    Object[] queryByWhereSql(String paramString) throws BusinessException;

    AggPickmVO[] queryByQueryScheme(IQueryScheme paramIQueryScheme, Integer paramInteger) throws BusinessException;

    AggPickmVO querySingleBillByPk(String paramString) throws BusinessException;

    AggPickmVO[] queryBillsByPks(String[] paramArrayOfString) throws BusinessException;

    MaterialRelationItem queryRelationItemForHead(MaterialQueryCondition paramMaterialQueryCondition) throws BusinessException;

    Map<String, MaterialVersionVO> queryMaterialVersionVOByPks(String[] paramArrayOfString) throws BusinessException;

    PickmItemVO queryPickmItemByPK(String paramString) throws BusinessException;

    Map<String, UFBoolean> queryHasDownFlowBill(String[] paramArrayOfString) throws BusinessException;

    Map<String, Map<String, UFBoolean>> queryNeededData(AggPickmVO[] paramArrayOfAggPickmVO) throws BusinessException;

    AggPickmVO[] queryPermData(AggPickmVO[] paramArrayOfAggPickmVO) throws BusinessException;

    Map<String, Object[]> queryAcceptLowerData(PickmHeadVO paramPickmHeadVO, PickmItemVO paramPickmItemVO) throws BusinessException;

    Map<String, Object[]> queryUnAcceptLowerData(String paramString) throws BusinessException;

    String querySCOrderStock(String paramString1, String paramString2) throws BusinessException;

    Map<String, PickmQueryMOParamForSetDelivery> queryMOInfo(String[] paramArrayOfString, boolean paramBoolean) throws BusinessException;

    PickmTransParamForPlanReplace[] queryMatSumPlanOutNumFromSameFirstBill(PickmTransParamForPlanReplace[] paramArrayOfPickmTransParamForPlanReplace) throws BusinessException;

    Object[] queryPSCPickmByQueryScheme(IQueryScheme paramIQueryScheme) throws BusinessException;

    Map<String, UFBoolean> queryIsHavePSCitemsByRowIDs(String[] paramArrayOfString) throws BusinessException;

    Map<String, String> queryVidByOidForOrgAndDept(List<String> paramList1, List<String> paramList2) throws BusinessException;

    PickmParamForAdd queryOrgvidAndTransinfForAdd(String paramString1, String paramString2) throws BusinessException;

    PickmHeadVO[] queryHeadByIds(String[] paramArrayOfString) throws BusinessException;

    PickmItemVO[] queryCLItemsForNcc(String paramString, String[] paramArrayOfString) throws BusinessException;

    PickmItemVO[] fillCLItemsForNcc(PickmItemVO[] paramArrayOfPickmItemVO) throws BusinessException;

    AggPickmVO[] queryAggPickmVObyBid(String[] paramArrayOfString) throws BusinessException;

    MapList<String, PickmItemVO> getReplaceGroupItemByKeyID(String[] paramArrayOfString, String paramString) throws BusinessException;

    PickmItemVO[] queryItemsByIds(String[] itemIds) throws BusinessException;
}
